﻿using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using Syncfusion.DocIORenderer;
using Syncfusion.Drawing;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Interactive;
using Syncfusion.Pdf.Parsing;
//using Syncfusion.Pdf;
using System.IO;

namespace ASPNetCoreConsole
{
    class Program
    {
        static void Main(string[] args)
        {
            string inpuFile = @"TemplateSign.docx";
            
            //Opens the template document 
            FileStream fileStreamPath = new FileStream(inpuFile, FileMode.Open, FileAccess.Read, FileShare.ReadWrite);
            WordDocument document = new WordDocument(fileStreamPath, FormatType.Docx);

            string[] fieldNames = new string[] { "Name", "CompanyName" };
            string[] fieldValues = new string[] { "Peter","Syncfusion" };
            //Performs the mail merge
            document.MailMerge.Execute(fieldNames, fieldValues);

            DocIORenderer renderer = new DocIORenderer();
            //Enable flag to preserve text form field
            renderer.Settings.PreserveFormFields = true;
            //Convert Word document to PDF
            PdfDocument pdf = renderer.ConvertToPDF(document);
            //Dispose the resources
            renderer.Dispose();

            //Saves the PDF document to MemoryStream
            MemoryStream stream = new MemoryStream();
            pdf.Save(stream);
            stream.Position = 0;
            //Add signature field in PDF
            AddSignature(stream);
            pdf.Close();
            document.Close();
            //Download Word document in the browser
            // return File(stream, "application/msword", "Sample.docx");


        }
        /// <summary>
        /// Adds signature field in PDF
        /// </summary>
        /// <param name="stream"></param>
        private static void AddSignature(MemoryStream stream)
        {
            //Load the PDF document
            PdfLoadedDocument loadedDocument = new PdfLoadedDocument(stream);

            //Get the loaded form
            PdfLoadedForm loadedForm = loadedDocument.Form;

            for (int i = 0; i < loadedForm.Fields.Count; i++)
            {
                if (loadedForm.Fields[i] is PdfLoadedTextBoxField)
                {
                    //Get the loaded text box field and fill it
                    PdfLoadedTextBoxField loadedTextBoxField = loadedForm.Fields[i] as PdfLoadedTextBoxField;

                    //Get bounds from an existing textbox field
                    RectangleF bounds = loadedTextBoxField.Bounds;

                    //Get page
                    PdfPageBase loadedPage = loadedTextBoxField.Page;

                    //Remove the field
                    loadedForm.Fields.Remove(loadedTextBoxField);

                    PdfSignatureField signatureField = new PdfSignatureField(loadedPage, "Signature");

                    //Set properties to the signature field. 

                    signatureField.Bounds = bounds;

                    signatureField.ToolTip = "Signature";

                    //Add the form field to the document
                    loadedDocument.Form.Fields.Add(signatureField);

                }

            }
            string outputFile = @"..\..\..\Output\output.pdf";
            //Save the document
            FileStream fileStream = new FileStream(outputFile, FileMode.OpenOrCreate, FileAccess.ReadWrite);
            loadedDocument.Save(fileStream);
            fileStream.Dispose();
            //Close the document
            loadedDocument.Close(true);
        }
    }
}
